==> qbittorrent-2.8.3.tar.gz: qbittorrent-2.8.3/src/searchengine/nova/engines/piratebay.py <==
#VERSION: 1.40
#AUTHORS: Fabien Devaux (fab@gnux.info)
#CONTRIBUTORS: Christophe Dumez (chris@qbittorrent.org)

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#    * Redistributions of source code must retain the above copyright notice,
#      this list of conditions and the following disclaimer.
#    * Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#    * Neither the name of the author nor the names of its contributors may be
#      used to endorse or promote products derived from this software without
#      specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

from novaprinter import prettyPrinter
import sgmllib
from helpers import retrieve_url, download_file

class piratebay(object):
	url = 'http://thepiratebay.org'
	name = 'The Pirate Bay'
	supported_categories = {'all': '0', 'movies': '200', 'music': '100', 'games': '400', 'software': '300'}
	
	def __init__(self):
		self.results = []
		self.parser = self.SimpleSGMLParser(self.results, self.url)
		
	def download_torrent(self, info):
		print download_file(info)

	class SimpleSGMLParser(sgmllib.SGMLParser):
		def __init__(self, results, url, *args):
			sgmllib.SGMLParser.__init__(self)
			self.td_counter = None
			self.current_item = None
			self.results = results
			self.url = url
			self.code = 0
			self.in_name = None

		def start_a(self, attr):
			params = dict(attr)
			if params['href'].startswith('/torrent/'):
				self.current_item = {}
				self.td_counter = 0
				self.code = params['href'].split('/')[2]
				self.current_item['desc_link'] = 'http://thepiratebay.org'+params['href'].strip()
				self.in_name = True
			elif params['href'].startswith('http://torrents.thepiratebay.org/%s'%self.code):
				self.current_item['link']=params['href'].strip()
				self.in_name = False

		def handle_data(self, data):
			if self.td_counter == 0:
				if self.in_name:
					if not self.current_item.has_key('name'):
						self.current_item['name'] = ''
					self.current_item['name']+= data.strip()
				else:
					#Parse size
					if 'Size' in data:
						self.current_item['size'] = data[data.index("Size")+5:]
						self.current_item['size'] = self.current_item['size'][:self.current_item['size'].index(',')]
			elif self.td_counter == 1:
				if not self.current_item.has_key('seeds'):
					self.current_item['seeds'] = ''
				self.current_item['seeds']+= data.strip()
			elif self.td_counter == 2:
				if not self.current_item.has_key('leech'):
					self.current_item['leech'] = ''
				self.current_item['leech']+= data.strip()

		def start_td(self,attr):
			if isinstance(self.td_counter,int):
				self.td_counter += 1
				if self.td_counter > 3:
					self.td_counter = None
					# Display item
					if self.current_item:
						self.current_item['engine_url'] = self.url
						if not self.current_item['seeds'].isdigit():
							self.current_item['seeds'] = 0
						if not self.current_item['leech'].isdigit():
							self.current_item['leech'] = 0
						prettyPrinter(self.current_item)
						self.results.append('a')
	def search(self, what, cat='all'):
		ret = []
		i = 0
		order = 'se'
		while True and i<11:
			results = []
			parser = self.SimpleSGMLParser(results, self.url)
			dat = retrieve_url(self.url+'/search/%s/%u/7/%s' % (what, i, self.supported_categories[cat]))
			print self.url+'/search/%s/%u/7/%s' % (what, i, self.supported_categories[cat])
			parser.feed(dat)
			parser.close()
			if len(results) <= 0:
				break
			i += 1

==> qbittorrent-3.0.2.tar.gz: qbittorrent-3.0.2/src/searchengine/nova/engines/piratebay.py <==
#VERSION: 1.50
#AUTHORS: Fabien Devaux (fab@gnux.info)
#CONTRIBUTORS: Christophe Dumez (chris@qbittorrent.org)

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#    * Redistributions of source code must retain the above copyright notice,
#      this list of conditions and the following disclaimer.
#    * Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#    * Neither the name of the author nor the names of its contributors may be
#      used to endorse or promote products derived from this software without
#      specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

from novaprinter import prettyPrinter
import sgmllib
from helpers import retrieve_url, download_file

class piratebay(object):
	url = 'http://thepiratebay.se'
	name = 'The Pirate Bay'
	supported_categories = {'all': '0', 'movies': '200', 'music': '100', 'games': '400', 'software': '300'}

	def __init__(self):
		self.results = []
		self.parser = self.SimpleSGMLParser(self.results, self.url)

	def download_torrent(self, info):
		print download_file(info)

	class SimpleSGMLParser(sgmllib.SGMLParser):
		def __init__(self, results, url, *args):
			sgmllib.SGMLParser.__init__(self)
			self.td_counter = None
			self.current_item = None
			self.results = results
			self.url = url
			self.code = 0
			self.in_name = None

		def start_a(self, attr):
			params = dict(attr)
			if params['href'].startswith('/torrent/'):
				self.current_item = {}
				self.td_counter = 0
				self.current_item['desc_link'] = 'http://thepiratebay.se'+params['href'].strip()
				self.in_name = True
			elif params['href'].startswith('magnet:'):
				self.current_item['link']=params['href'].strip()
				self.in_name = False

		def handle_data(self, data):
			if self.td_counter == 0:
				if self.in_name:
					if not self.current_item.has_key('name'):
						self.current_item['name'] = ''
					self.current_item['name']+= data.strip()
				else:
					#Parse size
					if 'Size' in data:
						self.current_item['size'] = data[data.index("Size")+5:]
						self.current_item['size'] = self.current_item['size'][:self.current_item['size'].index(',')]
			elif self.td_counter == 1:
				if not self.current_item.has_key('seeds'):
					self.current_item['seeds'] = ''
				self.current_item['seeds']+= data.strip()
			elif self.td_counter == 2:
				if not self.current_item.has_key('leech'):
					self.current_item['leech'] = ''
				self.current_item['leech']+= data.strip()

		def start_td(self,attr):
			if isinstance(self.td_counter,int):
				self.td_counter += 1
				if self.td_counter > 3:
					self.td_counter = None
					# Display item
					if self.current_item:
						self.current_item['engine_url'] = self.url
						if not self.current_item['seeds'].isdigit():
							self.current_item['seeds'] = 0
						if not self.current_item['leech'].isdigit():
							self.current_item['leech'] = 0
						prettyPrinter(self.current_item)
						self.results.append('a')
	def search(self, what, cat='all'):
		ret = []
		i = 0
		order = 'se'
		while True and i<11:
			results = []
			parser = self.SimpleSGMLParser(results, self.url)
			dat = retrieve_url(self.url+'/search/%s/%d/7/%s' % (what, i, self.supported_categories[cat]))
			parser.feed(dat)
			parser.close()
			if len(results) <= 0:
				break
			i += 1
